part of capsule;

enum SignTypedDataVersion {
  v1,
  v3,
  v4;

  String get jsValue => name.toUpperCase();
}

/// Additional signing functionality, implemented using metamask utils.
///
/// Currently in development and subject to change.
class CapsuleSigner {
  const CapsuleSigner(this.capsule);

  /// The `Capsule` instance to use for signing.
  final Capsule capsule;

  /// Signs a typed message.
  ///
  /// Returns the signature in hex format.
  Future<FullSignatureResult> signTypedData({
    required String from,
    required Map<String, dynamic> data,
    SignTypedDataVersion version = SignTypedDataVersion.v1,
  }) async {
    final result = await capsule._postMessage('signTypedData', [
      from,
      data,
      {'version': version.jsValue},
    ]);
    return FullSignatureResult.fromMap(result[0]);
  }

  /// Validates a typed data signature.
  ///
  /// Returns the address of the sender.
  Future<String> recoverTypedSignature({
    required dynamic data,
    required String signature,
    SignTypedDataVersion version = SignTypedDataVersion.v4,
  }) async {
    final result = await capsule._postMessage(
        'recoverTypedSignature', [data, signature, version.jsValue]);
    return result[0];
  }
}
