part of capsule;

/// Typed data domain to use for ethers signing.
class TypedDataDomain {
  const TypedDataDomain({
    this.name,
    this.version,
    this.chainId,
    this.verifyingContract,
    this.salt,
  });

  /// Human-readable name of the signing domain.
  final String? name;

  /// Major version of the signing domain.
  final String? version;

  /// Chain ID of the signing domain.
  ///
  /// The string will be parsed into a BigInt.
  final String? chainId;

  /// Address of the contract that will verify the signature.
  final String? verifyingContract;

  /// Salt used for purposes decided by the specific domain.
  final Uint8List? salt;

  /// Converts the domain to a map.
  Map<String, dynamic> toMap() {
    return {
      'name': name,
      'version': version,
      'chainId': chainId,
      'verifyingContract': verifyingContract,
      'salt': salt == null ? null : base64Encode(salt!),
    };
  }
}
