/// Result of a successful signature request.
class SuccessfulSignatureResult extends FullSignatureResult {
  SuccessfulSignatureResult(this.signature);

  /// The signature of the transaction.
  final String signature;
}

/// Result of a denied signature request.
class DeniedSignatureResult extends FullSignatureResult {
  DeniedSignatureResult(this.pendingTransactionId);

  /// The id of the pending transaction that was denied.
  final String pendingTransactionId;
}

/// Result of a denied signature request that has a review url.
class DeniedSignatureResWithUrl extends DeniedSignatureResult {
  DeniedSignatureResWithUrl(
      this.transactionReviewUrl, String pendingTransactionId)
      : super(pendingTransactionId);

  /// The url to review the transaction.
  final String transactionReviewUrl;
}

/// Base class for results of signature requests.
abstract class FullSignatureResult {
  static fromMap(Map<String, dynamic> result) {
    if (result['signature'] != null) {
      return SuccessfulSignatureResult(result['signature']);
    } else if (result['transactionReviewUrl'] != null) {
      return DeniedSignatureResWithUrl(
        result['transactionReviewUrl'],
        result['pendingTransactionId'],
      );
    } else {
      return DeniedSignatureResult(result['pendingTransactionId']);
    }
  }
}
